@@ -378,6 +378,21 @@ def _push_to_registry(registry, fqdn_image):
 
 
 def _prepare_build_container(registry, image, tag, git_revision, container_context, username, password, use_cache):
+    def runner_run(command):
+        """
+        All output generated by the container runtime during this stage should
+        not be included in stdout - we should redirect it to stderr, as the
+        user is just using skipper as a wrapper to run commands like make, run
+        etc - they don't care that as a side-effect of running their commands a
+        container is being built, and they don't want the output from that
+        build process to be included in the stdout for the commands they wrap
+        with skipper.
+
+        This allows users to do things like VERSION=$(skipper make get_version)
+        without having the build process output be included in their VERSION
+        env var.
+        """
+        return runner.run(command, stdout_to_stderr=True)
 
     if tag is not None:
 
@@ -408,22 +423,26 @@ def _prepare_build_container(registry, image, tag, git_revision, container_conte
         build_context = '.'
 
     command = ['build', '--network=host', '-t', tagged_image_name, '-f', docker_file, build_context]
+
+    for cmd_limit in utils.SKIPPER_ULIMIT:
+        command += cmd_limit
+
     if use_cache:
         cache_image = utils.generate_fqdn_image(registry, namespace=None, image=image, tag=DOCKER_TAG_FOR_CACHE)
-        runner.run(['pull', cache_image])
+        runner_run(['pull', cache_image])
         command.extend(['--cache-from', cache_image])
-    ret = runner.run(command)
-    if ret != 0:
+
+    if runner_run(command) != 0:
         exit('Failed to build image: %(image)s' % dict(image=image))
 
     if git_revision and not git.uncommitted_changes():
         utils.logger.info("Tagging image with git revision: %(tag)s", dict(tag=tag))
-        runner.run(['tag', image, tagged_image_name])
+        runner_run(['tag', image, tagged_image_name])
 
     if use_cache:
         cache_image = utils.generate_fqdn_image(registry, namespace=None, image=image, tag=DOCKER_TAG_FOR_CACHE)
-        runner.run(['tag', image, cache_image])
-        runner.run(['push', cache_image])
+        runner_run(['tag', image, cache_image])
+        runner_run(['push', cache_image])
 
     return image
 
