@@ -17,7 +17,7 @@ def get_default_net():
 
 # pylint: disable=too-many-arguments
 def run(command, fqdn_image=None, environment=None, interactive=False, name=None, net=None, publish=(), volumes=None,
-        workdir=None, use_cache=False, workspace=None, env_file=()):
+        workdir=None, use_cache=False, workspace=None, env_file=(), stdout_to_stderr=False):
 
     if not net:
         net = get_default_net()
@@ -26,15 +26,17 @@ def run(command, fqdn_image=None, environment=None, interactive=False, name=None
         return _run_nested(fqdn_image, environment, command, interactive, name, net, publish, volumes,
                            workdir, use_cache, workspace, env_file)
 
-    return _run(command)
+    return _run(command, stdout_to_stderr=stdout_to_stderr)
 
 
-def _run(cmd_args):
+def _run(cmd_args, stdout_to_stderr=False):
     logger = logging.getLogger('skipper')
     cmd = [utils.get_runtime_command()]
     cmd.extend(cmd_args)
     logger.debug(' '.join(cmd))
-    proc = subprocess.Popen(cmd)
+    proc = (subprocess.Popen(cmd)
+            if not stdout_to_stderr else
+            subprocess.Popen(cmd, stdout=sys.stderr))
     proc.wait()
     return proc.returncode
 
@@ -60,6 +62,9 @@ def _run_nested(fqdn_image, environment, command, interactive, name, net, publis
     else:
         cmd += ['--rm']
 
+    for cmd_limit in utils.SKIPPER_ULIMIT:
+        cmd += cmd_limit
+
     cmd += ['--privileged']
 
     cmd = handle_networking(cmd, publish, net)
@@ -76,6 +81,7 @@ def _run_nested(fqdn_image, environment, command, interactive, name, net, publis
     cmd += ['-e', 'SKIPPER_USERNAME=%(user)s' % dict(user=user)]
     cmd += ['-e', 'SKIPPER_UID=%(user_id)s' % dict(user_id=user_id)]
     cmd += ['-e', 'HOME=%(homedir)s' % dict(homedir=homedir)]
+    cmd += ['-e', 'CONTAINER_RUNTIME_COMMAND=%(runtime_command)s' % dict(runtime_command=utils.get_runtime_command())]
 
     if utils.get_runtime_command() == "docker":
         try:
